Pear
--------

Pear is a library that aims at offering a visual representation of neural networks. It can read networks built using Google's TensorFlow in and, for each requested layer, draw the associated decision boundaries.

Pear is still in the development process.

To use, do::
	>>> import pearlib
